<?xml version="1.0"?> 

<!--

$Id: rss.xsl,v 1.2 2002/09/13 00:24:58 burtonator Exp $

Copyright (C) 2000-2003 Kevin A. Burton (burton@openprivacy.org)

This program is free software; you can redistribute it and/or modify it under
the terms of the LICENSE which you should have obtaind with this package.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE.

-->

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
                xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
                xmlns:dc="http://purl.org/dc/elements/1.1/" 
                xmlns:dcterms="http://purl.org/dc/terms/"
                xmlns:rss="http://purl.org/rss/1.0/"
                xmlns:content="http://purl.org/rss/1.0/modules/content/"
                xmlns:annotate="http://purl.org/rss/1.0/modules/annotate/"
                xmlns:admin="http://webns.net/mvcb/"
                xmlns:image="http://purl.org/rss/1.0/modules/image/"
                xmlns:cc="http://web.resource.org/cc/"
                xmlns:reqv="http://purl.org/rss/1.0/modules/richequiv/"
                exclude-result-prefixes="rdf dc dcterms rss im content rss-simple im annotate admin image cc reqv"
                version="1.0">
    
    <xsl:output indent="yes" 
                method="html"
                omit-xml-declaration="yes"/>

    <!-- RSS 0.9 and 1.0 support -->
    <xsl:template match="/rdf:RDF">

        <html>

            <head>

                <title><xsl:value-of select="rss:channel/rss:title"/></title>
                <link href="http://purl.org/rss/1.0/style" type="text/css" rel="stylesheet" />

            </head>

            <body>

                <xsl:apply-templates select="rss:channel"/>

                <blockquote>

                <xsl:apply-templates select="rss:item">

                    <xsl:sort select="rss:title"/>

                </xsl:apply-templates>

                </blockquote>

            </body>

        </html>

    </xsl:template>

    <xsl:template match="rss:channel">

        <xsl:call-template name="channel">

            <xsl:with-param name="title" select="rss:title"/>
            <xsl:with-param name="link" select="rss:link"/>
            <xsl:with-param name="description" select="rss:description"/>
            <xsl:with-param name="image-link" select="../rss:image/rss:link"/>
            <xsl:with-param name="image-url" select="../rss:image/rss:url"/>

        </xsl:call-template>

    </xsl:template>

    <xsl:template match="rss:item">

        <xsl:call-template name="item">

            <xsl:with-param name="title" select="rss:title"/>
            <xsl:with-param name="link" select="rss:link"/>
            <xsl:with-param name="description" select="rss:description"/>

        </xsl:call-template>

    </xsl:template>

    <!-- =================================================================== -->
    <!--                      METAINFO TEMPLATES                             -->
    <!-- =================================================================== -->

    <xsl:template match="dc:*|dcterms:*|language|rss:language|lastBuildDate|rss:lastBuildDate|category|managingEditor|webmaster|rss:webMaster|copyright|pubDate|rss:pubDate">

        <xsl:choose>

            <xsl:when test="name(.) = 'dcterms:isPartOf'">

                <span class="metainfo-topic">
                    part of:
                </span>

                <span class="metainfo-entry">
                    <a href="{.}"><xsl:value-of select="."/></a>
                </span>

            </xsl:when>

            <xsl:when test=". != ''">

                <span class="metainfo-topic">
                    <xsl:value-of select="local-name(.)"/>: 
                </span>
                
                <span class="metainfo-entry">
                    <xsl:value-of select="."/>
                </span>
                
            </xsl:when>

        </xsl:choose>

    </xsl:template>

    <!--
         Handle all dublin core metainfo...
     -->
    <xsl:template name="metainfo">
        
        <xsl:apply-templates select="dc:subject"/>
        <xsl:apply-templates select="dc:date"/>
        <xsl:apply-templates select="dcterms:created"/>
        <xsl:apply-templates select="dcterms:valid"/>
        <xsl:apply-templates select="dcterms:available"/>
        <xsl:apply-templates select="dcterms:issued"/>
        <xsl:apply-templates select="dcterms:modified"/>
        <xsl:apply-templates select="dc:creator"/>
        <xsl:apply-templates select="dc:publisher"/>
        <xsl:apply-templates select="dc:contributor"/>
        <xsl:apply-templates select="dc:type"/>
        <xsl:apply-templates select="dc:language"/>
        <xsl:apply-templates select="dc:coverage"/>
        <xsl:apply-templates select="dcterms:spatial"/>
        <xsl:apply-templates select="dcterms:temporal"/>
        <xsl:apply-templates select="dc:rights"/>
        <xsl:apply-templates select="dc:format"/>
        <xsl:apply-templates select="dcterms:extent"/>
        <xsl:apply-templates select="dcterms:medium"/>
        <xsl:apply-templates select="dc:identifier"/>
        <xsl:apply-templates select="dc:relation"/>
        <xsl:apply-templates select="dc:audience"/>
        <xsl:apply-templates select="dcterms:dateAccepted"/>
        <xsl:apply-templates select="dcterms:dateSubmitted"/>
        <xsl:apply-templates select="dcterms:dateCopyrighted"/>

        <!-- RSS 0.91 support -->
        <xsl:apply-templates select="language"/>
        <xsl:apply-templates select="rss:language"/>
        <xsl:apply-templates select="lastBuildDate"/>
        <xsl:apply-templates select="rss:lastBuildDate"/>
        <xsl:apply-templates select="category"/>
        <xsl:apply-templates select="managingEditor"/>
        <xsl:apply-templates select="webmaster"/>
        <xsl:apply-templates select="rss:webMaster"/>
        <xsl:apply-templates select="copyright"/>
        <xsl:apply-templates select="pubDate"/>
        <xsl:apply-templates select="rss:pubDate"/>

        <xsl:apply-templates select="dcterms:isPartOf"/>

    </xsl:template>

    <!-- =================================================================== -->
    <!--                        NAMED TEMPLATES                              -->
    <!-- =================================================================== -->

    <!-- 

         Create an item entry with title, link and description.  We disable
         output escaping so that users can syndicate HTML content.  Although
         this is not really XML compliant is seems like common practice and
         since it doesn't break anything we are going to enable this.

         -->
    <xsl:template name="item">

        <xsl:param name="title"/>
        <xsl:param name="link"/>
        <xsl:param name="description" select="''"/>

        <li style="margin-bottom: 8; margin-top: 8;">
            <a href="{$link}" class="title" style="margin-right: 5;">
                <xsl:value-of select="$title" disable-output-escaping="yes"/>
            </a>
        </li>
        
        <div style="margin-left: 16;">

            <xsl:value-of select="$description" disable-output-escaping="yes"/>

        </div>

    </xsl:template>

    <xsl:template name="channel">

        <xsl:param name="title"/>
        <xsl:param name="link"/>
        <xsl:param name="description"/>
        <xsl:param name="image-link"/>
        <xsl:param name="image-url"/>

        <h1>
            <xsl:value-of select="$title"/>
        </h1>
        
        <p>

            <xsl:value-of select="$description" disable-output-escaping="yes"/>

        </p>

    </xsl:template>

</xsl:stylesheet>

